pub struct EventTypeBuilder<'a> { /* private fields */ }Expand description
Builder for configuring type information on a SessionBuilder.
Obtained by calling SessionBuilder::declare_type. Use define_record
to define a record-shaped type. Call done to return to the SessionBuilder.
Implementations
Sourceimpl<'a> EventTypeBuilder<'a>
impl<'a> EventTypeBuilder<'a>
Sourcepub fn define_record(self) -> EventTypeRecordBuilder<'a>
pub fn define_record(self) -> EventTypeRecordBuilder<'a>
Starts building a record-shaped event type with named fields.
Sourcepub fn data_source(self, data_source: &str, tpe: Type) -> Self
pub fn data_source(self, data_source: &str, tpe: Type) -> Self
Registers a type for a specific named data source.
Queries targeting data_source will use tpe for type checking instead of the default event type.
Data source names are case-insensitive.
Sourcepub fn done(self)
pub fn done(self)
Finalizes type configuration and returns the SessionBuilder.